# porygon [![Build Status](https://travis-ci.org/nikolassilva/porygon.svg)](https://travis-ci.org/nikolassilva/porygon) [![Dependency Status](https://david-dm.org/nikolassilva/porygon.svg)](https://david-dm.org/nikolassilva/porygon) [![devDependency Status](https://david-dm.org/nikolassilva/porygon/dev-status.svg)](https://david-dm.org/nikolassilva/porygon#info=devDependencies)
> ![porygon-icon](http://i.imgur.com/gtPOmiM.gif) Easy-to-use download module with no dependencies


## Install
```bash
$ npm install --save porygon 
```


## Usage
```js
'use strict';

const porygon = require('porygon');

// If you want to download a single file
porygon.download('http://example.com/foobar.jpg', {
    filename: 'baz.jpg',
    dest: 'tmp/'
}).then(file => {
  console.log(`${file.name} was downloaded.`);
});

// If you just want the buffer of the file
porygon.buffer('http://example.com/foobar.jpg')
.then(data => {
  require('fs').writeFileSync('foobar.jpg', data);
});

// Or if you want to download multiple files in parallel
let options = {
  dest: 'imgs/',
  forEach: (file) => {
    console.log(`Got ${file.name}.`);
  }
};

porygon.downloadList([
  { url: 'http://foobar.com/example.png', filename: 'foobar.png' },
  { url: 'http://example.com/baz.jpg' },
  { url: 'http://bazbar.com/foo.jpg', filename: 'bazbar.jpg' }
], options).then(() => {
  console.log('All files downloaded successfully.');
});
```


## API

### .buffer(url)
Should return a promise which resolves a [Buffer](https://nodejs.org/api/buffer.html) of the content.


#### url

Type: `string`

Description: The URL to download.

---

### .download(url [, options])
Should return a promise which resolves an Object with the file path properties: `dir`, `name`, `ext` and `path`.


#### url

Type: `string`

Description: The URL to download.


#### options

Type: `Object`

Description: A bunch of options to set.


#### options.dest

Type: `string`

Description: Set the destination folder of the file to be downloaded.


#### options.filename

Type: `string`

Description: Set the name that the file will be saved as.

---

### .downloadList(files [, options])
Should return a promise, resolves when all files are downloaded.


#### files

Type: `Array`

Description: A list of Objects with `url` and `filename` properties.


#### options

Type: `Object`

Description: A bunch of options to set.


#### options.dest

Type: `string`

Description: Set the destination folder of the file to be downloaded.


#### options.limit

Type: `number`

Description: Set the limit of downloads in parallel. Defaults to 200.


#### options.forEach

Type: `Function`

Description: A function that gets executed each time a download completes. Receives an Object with the file path properties (`dir`, `name`, `ext` and `path`) as param.


## License
MIT